:mod:`art.estimators`
=====================
.. automodule:: art.estimators

Base Class Estimator
--------------------
.. autoclass:: BaseEstimator
   :members:

Mixin Base Class Loss Gradients
-------------------------------
.. autoclass:: LossGradientsMixin
   :members:

Mixin Base Class Neural Networks
--------------------------------
.. autoclass:: NeuralNetworkMixin
   :members:

Mixin Base Class Decision Trees
-------------------------------
.. autoclass:: DecisionTreeMixin
   :members:

Base Class KerasEstimator
-------------------------
.. autoclass:: KerasEstimator
   :members:
   :special-members: __init__
   :inherited-members:

Base Class MXEstimator
----------------------
.. autoclass:: MXEstimator
   :members:
   :special-members: __init__
   :inherited-members:

Base Class PyTorchEstimator
---------------------------
.. autoclass:: PyTorchEstimator
   :members:
   :special-members: __init__
   :inherited-members:

Base Class ScikitlearnEstimator
-------------------------------
.. autoclass:: ScikitlearnEstimator
   :members:
   :special-members: __init__
   :inherited-members:

Base Class TensorFlowEstimator
------------------------------
.. autoclass:: TensorFlowEstimator
   :members:
   :special-members: __init__
   :inherited-members:

Base Class TensorFlowV2Estimator
--------------------------------
.. autoclass:: TensorFlowV2Estimator
   :members:
   :special-members: __init__
   :inherited-members:
